local maximized = true;

--Creating the mainframe
local MainFrame = CreateFrame("Frame", "MainFrame", UIParent, "BasicFrameTemplateWithInset");
MainFrame:SetSize(0, 0);
MainFrame:SetPoint("CENTER", UIParent, "CENTER");

-- Make the frame movable
MainFrame:EnableMouse(true);
MainFrame:SetMovable(true);
MainFrame:RegisterForDrag("LeftButton");
MainFrame:SetScript("OnDragStart", MainFrame.StartMoving);
MainFrame:SetScript("OnDragStop", MainFrame.StopMovingOrSizing);

-- Create the fontstrings

--Titlebar:
MainFrame.title = MainFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlight");
MainFrame.title:SetPoint("LEFT", MainFrame.TitleBg, "LEFT", 5, 0);
MainFrame.title:SetText("Simple DPS");

-- Reset button:
MainFrame.resetBtn = CreateFrame("Button", nil, MainFrame, "GameMenuButtonTemplate");
MainFrame.resetBtn:SetPoint("RIGHT", MainFrame.TitleBg, "RIGHT", 0, 0);
MainFrame.resetBtn:SetSize(60, 15);
MainFrame.resetBtn:SetText("Reset");
MainFrame.resetBtn:SetNormalFontObject("GameFontNormalSmall");
MainFrame.resetBtn:SetHighlightFontObject("GameFontNormalSmall");
MainFrame.resetBtn:SetScript("OnClick", function(self, button) simpleDpsPlayerStatsTable.reset(); SimpleDpsGui.updateGui(tableSize(simpleDpsPlayerStatsTable.getPlayerStats()), simpleDpsPlayerStatsTable.getPlayerStats()); end)

-- Reset button:
MainFrame.minMaxBtn = CreateFrame("Button", nil, MainFrame, "GameMenuButtonTemplate");
MainFrame.minMaxBtn:SetPoint("RIGHT", MainFrame.TitleBg, "RIGHT", -60, 0);
MainFrame.minMaxBtn:SetSize(60, 15);
MainFrame.minMaxBtn:SetText("Minimize");
MainFrame.minMaxBtn:SetNormalFontObject("GameFontNormalSmall");
MainFrame.minMaxBtn:SetHighlightFontObject("GameFontNormalSmall");
MainFrame.minMaxBtn:SetScript("OnClick", function(self, button) maximized = not maximized; if maximized then MainFrame.minMaxBtn:SetText("Minimize"); else MainFrame.minMaxBtn:SetText("Maximize"); end SimpleDpsGui.updateGui(tableSize(simpleDpsPlayerStatsTable.getPlayerStats()), simpleDpsPlayerStatsTable.getPlayerStats()); end);

-- All the fonts with the players name and their dps
MainFrame.nameFonts = {}
MainFrame.dpsFonts = {}

for i = 1, 25 do
    MainFrame.nameFonts[i] = MainFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlightLarge");
    MainFrame.nameFonts[i]:SetPoint("TOPLEFT", MainFrame, "TOPLEFT", 15, -32 - 25 * (i - 1));
    MainFrame.nameFonts[i]:SetText("");

    MainFrame.dpsFonts[i] = MainFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal");
    MainFrame.dpsFonts[i]:SetPoint("TOPRIGHT", MainFrame, "TOPRIGHT", -15, -34 - 25 * (i - 1));
    MainFrame.dpsFonts[i]:SetText("");
end

-- Functions that are callable from another file.
SimpleDpsGui = {};

SimpleDpsGui.updateGui = function(numberOfPlayers, playerStats)
    local sortedList = {};

    for player, stats in pairs(playerStats) do
        if stats[3] > 0 then
            tinsert(sortedList, {player, stats[1], stats[3]})
        end
    end

    table.sort(sortedList, function(a,b) return a[2] > b[2] end)
    local numberOfPlayers = tableSize(sortedList);
    if numberOfPlayers < 1 then numberOfPlayers = 1; end

    if maximized then
        MainFrame:SetSize(275, 60 + (numberOfPlayers - 1) * 25);
    else
        MainFrame:SetSize(275, 60);
    end

    local index = 1;
    for i, stats in ipairs(sortedList) do
        MainFrame.nameFonts[index]:SetFontObject("GameFontHighlightLarge");

        if not MainFrame.nameFonts[index]:IsShown() or not MainFrame.dpsFonts[index]:IsShown() then
            MainFrame.nameFonts[index]:Show();
            MainFrame.dpsFonts[index]:Show();
        end

        MainFrame.nameFonts[index]:SetText(stats[1]);
        MainFrame.dpsFonts[index]:SetText(format_thousand(stats[2]) .. " (" .. format_thousand(stats[3]) .. ")");

        if stats[1] == UnitName("player") then
            MainFrame.nameFonts[index]:SetFontObject("GameFontRedLarge");
        end

        index = index + 1;
    end

    if not maximized then
        index = 2;
        MainFrame.nameFonts[1]:Show();
        MainFrame.nameFonts[1]:SetText("Maximize to see damage/DPS.");
        MainFrame.dpsFonts[1]:Hide();
    end

    for i = index, 25 do
        MainFrame.nameFonts[i]:Hide();
        MainFrame.dpsFonts[i]:Hide();
    end
end

SimpleDpsGui.toggleGui = function()
    if MainFrame:IsVisible() then
        MainFrame:Hide();
    else
        MainFrame:Show();
    end
end

--Settings frame found in settings menu.
local settingsFrame = CreateFrame("Frame", "SimpleDpsSettingsFrame", UIParent, "BasicFrameTemplateWithInset");
settingsFrame:SetSize(0, 0);
settingsFrame:SetPoint("CENTER", UIParent, "CENTER");
settingsFrame.name = "Simple DPS Settings";
InterfaceOptions_AddCategory(settingsFrame);

--Titlebar:
settingsFrame.title = settingsFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlight");
settingsFrame.title:SetPoint("LEFT", settingsFrame.TitleBg, "LEFT", 5, 0);
settingsFrame.title:SetText("Simple DPS settings menu.");

--Togglebutton:
settingsFrame.toggleBtn = CreateFrame("Button", nil, settingsFrame, "GameMenuButtonTemplate");
settingsFrame.toggleBtn:SetPoint("TOPLEFT", settingsFrame, "TOPLEFT", 20, -40);
settingsFrame.toggleBtn:SetSize(150, 30);
settingsFrame.toggleBtn:SetText("Toggle Simple DPS");
settingsFrame.toggleBtn:SetNormalFontObject("GameFontNormalSmall");
settingsFrame.toggleBtn:SetHighlightFontObject("GameFontNormalSmall");
settingsFrame.toggleBtn:SetScript("OnClick", function(self, button) SimpleDpsGui.toggleGui();  end);

settingsFrame.infoFont = settingsFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall");
settingsFrame.infoFont:SetPoint("TOPLEFT", settingsFrame, "TOPLEFT", 23, -80);
settingsFrame.infoFont:SetText("This button shows/hides the Simple DPS frame.");

settingsFrame.infoFont = settingsFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall");
settingsFrame.infoFont:SetPoint("TOPLEFT", settingsFrame, "TOPLEFT", 23, -100);
settingsFrame.infoFont:SetText("You can also type /tsd (Toggle Simple Dps) to toggle.");

--Slash command for toggling gui.
SLASH_TOGGLE_GUI1 = '/tsd';
function SlashCmdList.TOGGLE_GUI(...)
    SimpleDpsGui.toggleGui();
end